==> apache-servicecomb-java-chassis-distribution-2.8.30-src.zip: apache-servicecomb-java-chassis-distribution-2.8.30-src/foundations/foundation-common/src/main/java/org/apache/servicecomb/foundation/common/event/EventManager.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.servicecomb.foundation.common.event;

import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

import com.google.common.eventbus.EventBus;

/**
 * EventManager for chassis events
 *
 */
@Configuration
public class EventManager {
  public static EventBus eventBus = new SimpleEventBus();

  public static EventBus getEventBus() {
    return eventBus;
  }

  /**
   * Registering listener.
   */
  public static void register(Object listener) {
    eventBus.register(listener);
  }

  /**
   * post event.
   */
  public static void post(Object event) {
    eventBus.post(event);
  }

  /**
   * Unregistering listener.
   */
  public static void unregister(Object listener) {
    eventBus.unregister(listener);
  }

  @Bean
  public EventBus eventBus() {
    return eventBus;
  }
}

==> apache-servicecomb-java-chassis-distribution-3.3.0-src.zip: apache-servicecomb-java-chassis-distribution-3.3.0-src/foundations/foundation-common/src/main/java/org/apache/servicecomb/foundation/common/event/EventManager.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.servicecomb.foundation.common.event;

import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

import com.google.common.eventbus.EventBus;

/**
 * EventManager for chassis events
 *
 */
@Configuration
public class EventManager {
  public static EventBus eventBus = new SimpleEventBus();

  public static EventBus getEventBus() {
    return eventBus;
  }

  /**
   * Registering listener.
   */
  public static void register(Object listener) {
    eventBus.register(listener);
  }

  /**
   * post event.
   */
  public static void post(Object event) {
    eventBus.post(event);
  }

  /**
   * Unregistering listener.
   */
  public static void unregister(Object listener) {
    eventBus.unregister(listener);
  }

  @Bean
  public EventBus scbEventBus() {
    return eventBus;
  }
}
